/*
 ***********************************************************************************************************************
 *
 * Copyright (c) 2015, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** MS           Mohamed Sassi                                                 **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-04-15, BG:   Initial version of revision history              **
** V1.0.1: 2020-07-21, BG:   EP-439:  Formatted .h/.c files                   **
** V1.0.2: 2020-08-04, BG:   EP-431:  Fixed ARMCC v6 compiler warnings        **
** V1.0.3: 2022-10-27, MS:   EP-1338: Handled clearing status flags           **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** ADC2: VS over- and undervoltage detection                                  **
********************************************************************************
** Enable VS over- and undervoltage interrupt.                                **
** LED6 will be on in case of VS undervoltage below 7V.                       **
** LED7 will be on in case of VS overvoltage above 18.5V.                     **
*******************************************************************************/

#include "tle_device.h"
#include "eval_board.h"

void Diagnostic_Status_Clear(void);

int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */
  TLE_Init();

  for (;;)
  {
    (void)WDT1_Service();
    Diagnostic_Status_Clear();
  }
}

#if defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6000000)
  #pragma clang diagnostic push
  #pragma clang diagnostic ignored "-Wmissing-prototypes"
#endif
/* Callback Function for ADC2 VS Upper Threshold Interrupt */
void VS_Over_Voltage_Diag(void)
{
  PORT_ChangePin(LED7, PORT_ACTION_SET);
}

/* Callback Function for ADC2 VS Lower Threshold Interrupt */
void VS_Under_Voltage_Diag(void)
{
  PORT_ChangePin(LED6, PORT_ACTION_SET);
}
#if defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6000000)
  #pragma clang diagnostic pop
#endif

void Diagnostic_Status_Clear(void)
{
  /* Check for VS overvoltage */
  if (SCUPM->SYS_SUPPLY_IRQ_STS.bit.VS_OV_STS == 1u)
  {
    /* Clear VS overvoltage status */
    SCUPM->SYS_SUPPLY_IRQ_CLR.bit.VS_OV_SCLR = 1u;
	/* Clear VS overvoltage status with '0' to add an extra MI_CLCK cycle */
    SCUPM->SYS_SUPPLY_IRQ_CLR.bit.VS_OV_SCLR = 0u;

    /* Status set again if overvoltage is still present */
    /* Status remains cleared if overvoltage is gone */
    if (SCUPM->SYS_SUPPLY_IRQ_STS.bit.VS_OV_STS == 0u)
    {
      /* If status stays clear, no more overvoltage condition and LED can be cleared */
      PORT_ChangePin(LED7, PORT_ACTION_CLEAR);
    }
  }

  /* Check for VS undervoltage */
  if (SCUPM->SYS_SUPPLY_IRQ_STS.bit.VS_UV_STS == 1u)
  {
    /* Clear VS undervoltage status */
    SCUPM->SYS_SUPPLY_IRQ_CLR.bit.VS_UV_SCLR = 1u;
	/* Clear VS undervoltage status with '0' to add an extra MI_CLCK cycle */
    SCUPM->SYS_SUPPLY_IRQ_CLR.bit.VS_UV_SCLR = 0u;

    /* Status set again if overvoltage is still present */
    /* Status remains cleared if overvoltage is gone */
    if (SCUPM->SYS_SUPPLY_IRQ_STS.bit.VS_UV_STS == 0u)
    {
      /* If status stays clear, no more overvoltage condition and LED can be cleared */
      PORT_ChangePin(LED6, PORT_ACTION_CLEAR);
    }
  }
}
