/*
 ***********************************************************************************************************************
 *
 * Copyright (c) 2015, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** ISLE         ISLE Ilmenau                                                  **
** BG           Blandine Guillot                                              **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2016-07-20, ISLE:   Initial version of revision history            **
** V1.0.1: 2020-04-15, BG:     Updated revision history                       **
** V1.0.2: 2020-07-21, BG:     EP-439: Formatted .h/.c files                  **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** BLDC BEMF: Motor Drive with sensorless block commutation (BEMF)            **
********************************************************************************
** This example is configured to work with the Trinamic QBL 4208-61-04-013    **
** motor.                                                                     **
** Press the MON button to have the motor run with 2000 rpm.                  **
** It is also possible to use negative speed to turn the motor in the         **
** opposite direction.                                                        **
*******************************************************************************/

#include <tle_device.h>
#include "Emo_BEMF.h"

static void Main_lStartMotor(void);
static void Main_lStopMotor(void);

static uint8 bMotorRun;

int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */
  TLE_Init();
  Emo_Init();
  Emo_setspeedreferenz(2000);

  for (;;)
  {
    /* Service watchdog */
    (void)WDT1_Service();

    /* Wait for MON button to be pressed */
    if (MON_Debounce(0u) == 0u)
    {
      if (bMotorRun == 0u)
      {
        /* Start motor to run up to the desired speed */
        Main_lStartMotor();
        bMotorRun = 1u;
      }
      else
      {
        /* Stop motor */
        Main_lStopMotor();
        /* Reinitialise motor control parameters */
        Emo_Init();
        bMotorRun = 0u;
      }

      /* Wait until MON button is released */
      while (MON_Debounce(1u) == 0u) {}
    }
  }
}


#if defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6000000)
  #pragma clang diagnostic push
  #pragma clang diagnostic ignored "-Wmissing-prototypes"
#endif
void Main_HandleSysTick(void)
{
}
#if defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6000000)
  #pragma clang diagnostic pop
#endif


static void Main_lStartMotor(void)
{
  uint32 Error;
  Error = EMO_ERROR_NONE;

  if (Error == EMO_ERROR_NONE)
  {
    Error = Emo_StartMotor();
  }

  if (Error == EMO_ERROR_NONE)
  {
  }
  else /* Error */
  {
  }
}


static void Main_lStopMotor(void)
{
  uint32 Error;
  Error = Emo_StopMotor();

  if (Error != EMO_ERROR_NONE)
  {
  }
}

