/*
 ***********************************************************************************************************************
 *
 * Copyright (c) 2015, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** CK           Chander Kumar                                                 **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-04-15, BG:   Initial version of revision history              **
** V1.0.1: 2020-07-21, BG:   EP-439: Formatted .h/.c files                    **
** V1.0.2: 2022-05-25, CK:   EP-1155: Added selection of motor in CW and       **
**                           modified hall patterns in EmoCcu_Cfg.c           **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** BLDC: Motor Drive with block commutation and Hall sensor                   **
********************************************************************************
** Use the Poti to start/stop and speed up the motor.                         **
** Motor connection, QBL4208:                                                 **
** Phase 1             : yellow                                               **
** Phase 2             : red                                                  **
** Phase 3             : black                                                **
** Hall A - P0.3       : blue  (Motor Hall A)                                 **
** Hall B - P0.4       : green (Motor Hall B)                                 **
** Hall C - P1.2       : white (Motor Hall C)                                 **
** Hall Supply - VDDEXT: red                                                  **
** Hall Gnd - GND      : black                                                **
**                                                                            **
** Motor connection, DB42S03 Nanotec:                                         **
** Phase 1             : yellow                                               **
** Phase 2             : red                                                  **
** Phase 3             : black                                                **
** Hall A - P0.3       : blue  (Motor Hall A)                                 **
** Hall B - P0.4       : white (Motor Hall B)                                 **
** Hall C - P1.2       : green (Motor Hall C)                                 **
** Hall Supply - VDDEXT: red                                                  **
** Hall Gnd - GND      : black                                                **
*******************************************************************************/

#include "tle_device.h"
#include "Emo.h"

static void Main_lStartMotor(void);
static void Main_lStopMotor(void);
void Poti_Handler(void);

int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */
  TLE_Init();
  /* Initialize E-Motor application */
  Emo_Init();
  /* Start poti readout after Emo has been initialized */
  ADC1_Ch4_Int_En();

  for (;;)
  {
    /* Service watchdog */
    (void)WDT1_Service();
  }
}


#if defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6000000)
  #pragma clang diagnostic push
  #pragma clang diagnostic ignored "-Wmissing-prototypes"
#endif
void Main_HandleSysTick(void)
{
  /* Callback function executed every ms for speed control */
  Emo_CtrlSpeed();
}
#if defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6000000)
  #pragma clang diagnostic pop
#endif


static void Main_lStartMotor(void)
{
  uint32 Error;
  Error = EMO_ERROR_NONE;

  if (Error == EMO_ERROR_NONE)
  {
    /* Start motor with desired positive or negative speed in [rpm] */
    Error = Emo_StartMotor();
  }

  if (Error == EMO_ERROR_NONE)
  {
  }
  else /* Error */
  {
  }
}


static void Main_lStopMotor(void)
{
  uint32 Error;
  Error = Emo_StopMotor();

  if (Error != EMO_ERROR_NONE)
  {
  }
}


void Poti_Handler(void)
{
  uint16 mV;

  /* Read the value at Ch4 (Poti) in mV - values between 0 and 5000 are possible */
  if (ADC1_GetChResult_mV(&mV, ADC1_CH4) == true)
  {
    Emo_SetRefSpeed(mV / 2);

    if (mV > 100)
    {
      Main_lStartMotor();
      PORT_P01_Output_High_Set();
    }
    else
    {
      Main_lStopMotor();
      PORT_P01_Output_Low_Set();
    }
  }
}
