/*
 ***********************************************************************************************************************
 *
 * Copyright (c) 2015, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/
 
 /******************************* Speedcontroller **********************************************\
 *                                   ________                                                  *
 *                                  |        |                                                 *
 *                             /--->| P_Gain |----\                                            *
 *                             |    |________|    |                                            *
 *  SC_Refspeed_Set(refspeed); |     ________     |     ______________  int Speed_Control()    *
 *       ->sc.refspeed         |    |        |  + |+   |              | -> sc.out              *
 *           -------->O--->--->O--->| I_Gain |--->O--->| SC_SCALE_OUT |-------------------->   *
 *                    |-       |    |________|   +|    |______________|                        *
 *                    |        |     ________     |                                            *
 *                    |        |    |        |    |                                            *
 *                    |        \--->| D_Gain |----/                                            *
 *                    |             |________|                SC_Actspeed_Set(int actspeed);   *
 *                    |                                       -> sc.actspeed                   *
 *                    \----<--------<----------<-----------<----------<----------<------       *
 *                                                                                             *
 **********************************************************************************************/

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "speedcontrol.h"

/*******************************************************************************
**                         Global Variable Definitions                        **
*******************************************************************************/
struct _speedcontrol sc;

/*******************************************************************************
**                        Global Function Definitions                         **
*******************************************************************************/
void Speed_Control_Init(void)
{
  sc.refspeed       = 0;
  sc.actspeed       = 0;
  sc.P_gain         = SC_P_GAIN;
  sc.P_value        = 0;
  sc.I_gain         = SC_I_GAIN;
  sc.I_value        = 0;
  sc.D_gain         = SC_D_GAIN;
  sc.D_value        = 0;
  sc.error          = 0;
  sc.error_Integral = 0;
  sc.error_diff     = 0;
  sc.out            = DUTYCYCLE_MIN;
}

int Speed_Control(void)
{
  int out;                                                                   /* help variable */
  sc.error           =  sc.refspeed - sc.actspeed;                           /* error calculation */
  sc.P_value         = (sc.error * sc.P_gain)/SC_SCALE_P;                    /* P_gain scaled 1 to 1000 */
  sc.error_Integral +=  sc.error ;                                           /* error Integral */
  if(sc.error_Integral >  SC_INTEGRAL_LIMIT){sc.error_Integral =  SC_INTEGRAL_LIMIT;}
  if(sc.error_Integral < -SC_INTEGRAL_LIMIT){sc.error_Integral = -SC_INTEGRAL_LIMIT;}
  sc.I_value         = (sc.error_Integral * sc.I_gain)/SC_SCALE_I;           /* I_gain scaled 1 to 1000 */
  sc.D_value         = ((sc.error_diff - sc.error)*sc.D_gain) / SC_SCALE_D;  /* D_gain scaled 1 to 1000 */
  sc.error_diff      =  sc.error;                                            /* old error is new error */
  out                =  sc.out + sc.P_value + sc.I_value + sc.D_value;       /* Speedcontrol output */
  
  out = out/SC_SCALE_OUT; /* Output scale to max_dutycycle */
  
  /* Limiter for Max and Min Dutycycle */
  if(out > DUTYCYCLE_MAX) { out = DUTYCYCLE_MAX;}
  if(out < DUTYCYCLE_MIN) { out = DUTYCYCLE_MIN;}
  
  sc.out = out;
  //sc.out = (3*sc.out+out)/4; // Set output variable /1 to 4 filter
  
  return out;
}

void SC_Refspeed_Set(int refspeed)
{
  sc.refspeed = (sc.refspeed+refspeed)/2;
}
void SC_Actspeed_Set(int actspeed)
{
  sc.actspeed = (sc.actspeed+actspeed)/2;
}
