/*
 ***********************************************************************************************************************
 *
 * Copyright (c) 2015, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-04-15, BG:   Initial version of revision history              **
** V1.0.1: 2020-07-21, BG:   EP-439: Formatted .h/.c files                    **
** V1.0.2: 2020-08-04, BG:   EP-431: Fixed ARMCC v6 compiler warnings         **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** CCU6 SIN PWM: Generation of three different PWMs (50us), 120, sinusoidal  **
********************************************************************************
** Timer12 is running at a 50us period in center-aligned mode.                **
** The three compare channel have a compare match at:                         **
** Channel | DC  | CC6x | COUT6x                                              **
** -----------------------------                                              **
**   Ch0   | sin | P0.4 | P0.2                                                **
**   Ch1   | sin | P1.0 | P1.1                                                **
**   Ch2   | sin | P1.3 | P1.4                                                **
*******************************************************************************/

#include "tle_device.h"
#include "sinus.h"
#include "eval_board.h"

static uint16 deg = 0;
static uint32 pc0, pc1;
  
int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */
  TLE_Init();
  CCU6_StartTmr_T12();

  for (;;)
  {
    (void)WDT1_Service();
  }
}


#if defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6000000)
  #pragma clang diagnostic push
  #pragma clang diagnostic ignored "-Wmissing-prototypes"
#endif
/* math.h : 379us runtime @ 40MHz */
/* sinus.h:  37us runtime @ 40MHz */
void Task_1ms(void)
{
  #define PI 3.14159265
  static double res;
  
  uint16 deg1, deg2;
  uint16 cmp0;
  uint16 cmp1;
  uint16 cmp2;
  pc0 = CPU->SYSTICK_CUR.reg;
  deg++;

  if (deg > 359)
  {
    deg = 0;
  }

  //res = sin(deg*PI/180);
  res = sinus[deg];
  cmp0 = (uint16) ((CCU6_T12PR / 2) * res + (CCU6_T12PR / 2));
  deg1 = deg + 120;

  if (deg1 > 359)
  {
    deg1 -= 360;
  }

  //res = sin(deg1*PI/180);
  res = sinus[deg1];
  cmp1 = (uint16) ((CCU6_T12PR / 2) * res + (CCU6_T12PR / 2));
  deg2 = deg + 240;

  if (deg2 > 359)
  {
    deg2 -= 360;
  }

  //res = sin(deg2*PI/180);
  res = sinus[deg2];
  cmp2 = (uint16) ((CCU6_T12PR / 2) * res + (CCU6_T12PR / 2));
  CCU6_LoadShadowRegister_CC60(cmp0);
  CCU6_LoadShadowRegister_CC61(cmp1);
  CCU6_LoadShadowRegister_CC62(cmp2);
  CCU6_EnableST_T12();
  pc1 = CPU->SYSTICK_CUR.reg;
}
#if defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6000000)
  #pragma clang diagnostic pop
#endif
