/*
 ***********************************************************************************************************************
 *
 * Copyright (c) 2015, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                                                                            **
**                _  _               ___             _                        **
**               (_)| |__   _ __    / _ \ _ __ ___  | |__    /\  /\           **
**               | || '_ \ | '__|  / /_\/| '_ ` _ \ | '_ \  / /_/ /           **
**               | || | | || |    / /_\\ | | | | | || |_) |/ __  /            **
**               |_||_| |_||_|    \____/ |_| |_| |_||_.__/ \/ /_/             **
**                                                                            **
**  ihr GmbH                                                                  **
**  Airport Boulevard B210                                                    **
**  77836 Rheinmnster - Germany                                              **
**  http://www.ihr.de                                                         **
**  Phone +49(0) 7229-18475-0                                                 **
**  Fax   +49(0) 7229-18475-11                                                **
**                                                                            **
********************************************************************************
**                                                                            **
** (c) Alle Rechte bei IHR GmbH, auch fuer den Fall von Schutzrechts-         **
** anmeldungen. Jede Verfuegungsbefugnis, wie Kopier- und Weitergaberecht     **
** bei uns.                                                                   **
**                                                                            **
** (c) All rights reserved by IHR GmbH including the right to file            **
** industrial property rights. IHR GmbH retains the sole power of             **
** disposition such as reproduction or distribution.                          **
**                                                                            **
*********************    Workfile:    main.c              **********************
**                                                                            **
** PROJECT-DESCRIPTION:  Infineon LIN Master Driver                           **
**                                                                            **
** FILE-DESCRIPTION:  main application file                                   **
**                                                                            **
*******************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BR           B.Roegl                                                       **
** HS           H. Spinner                                                    **
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2014-02-18, HS:   New Demo driver for Infineon TLE987x             **
** V1.0.1: 2020-04-15, BG:   Updated abstract                                 **
** V1.0.2: 2020-07-21, BG:   EP-439: Formatted .h/.c files                    **
** V1.1.0: 2022-07-07, JO:   EP-1206: Updated LIN example to the following    **
**                           signal: min = 0, max = 5000, scale = 1,          **
**                           offset = -2500                                   **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** LIN: Configuration as master                                               **
********************************************************************************
** This example is working in combination with the LIN_SLAVE example.         **
** The Poti position is read out at ADC1-CH4, measuring Ch4 in sequencer mode.**
** This value is written into RefSpeed and sent to the slave board over LIN.  **
*******************************************************************************/

#include "linmain.h"
#include "genLinConfig.h"
#include "lin_driver_api.h"

uint16 Poti_Value_mV;
void Poti_LED_Display(uint16 mV);

int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */
  TLE_Init();
  /* Initialize LIN LLD */
  LIN_LLD_Init();
  /* Start LIN scheduler */
  l_sch_set(0u, 0u);

  for (;;)
  {
    (void)WDT1_Service();
    /* Handle LIN service */
    LIN_LLD_Service();
    /* Display the poti value on the board LEDs */
    Poti_LED_Display(Poti_Value_mV);
  }
}

void Poti_LED_Display(uint16 mV)
{
#define Interval_mV 625u

  if (mV == 0u)
  {
    PORT_P01_Output_Low_Set();
  }

  if (mV > (0u * Interval_mV))
  {
    PORT_P01_Output_High_Set();
    PORT_P02_Output_Low_Set();
  }

  if (mV > (1u * Interval_mV))
  {
    PORT_P02_Output_High_Set();
    PORT_P03_Output_Low_Set();
  }

  if (mV > (2u * Interval_mV))
  {
    PORT_P03_Output_High_Set();
    PORT_P12_Output_Low_Set();
  }

  if (mV > (3u * Interval_mV))
  {
    PORT_P12_Output_High_Set();
    PORT_P10_Output_Low_Set();
  }

  if (mV > (4u * Interval_mV))
  {
    PORT_P10_Output_High_Set();
    PORT_P13_Output_Low_Set();
  }

  if (mV > (5u * Interval_mV))
  {
    PORT_P13_Output_High_Set();
    PORT_P14_Output_Low_Set();
  }

  if (mV > (6u * Interval_mV))
  {
    PORT_P14_Output_High_Set();
    PORT_P04_Output_Low_Set();
  }

  if (mV > (7u * Interval_mV))
  {
    PORT_P04_Output_High_Set();
  }
}

void Poti_Value(void)
{
  /* Read the value at Ch4 (Poti) in mV *
   * Values between 0 and 5000 are possible */
  if (ADC1_GetChResult_mV(&Poti_Value_mV, ADC1_CH4) == true)
  {
    /* Write the Poti value as speed parameter onto LIN */
    l_u16_wr_RefSpeed(Poti_Value_mV);
  }
}
